# Table of Contents

- [searching-and-filtering-in-inventory](<./searching-and-filtering-in-inventory.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Searching and Filtering in the Inventory](<./Searching-and-Filtering-in-the-Inventory.md>)
  - [Introduction](<./Searching-and-Filtering-in-the-Inventory/Introduction.md>)
  - [Searching and Filtering](<./Searching-and-Filtering-in-the-Inventory/Searching-and-Filtering.md>)
  - [Searching and Applying Filters](<./Searching-and-Filtering-in-the-Inventory/Searching-and-Applying-Filters.md>)
  - [Searching and Filtering Using Natural Language](<./Searching-and-Filtering-in-the-Inventory/Searching-and-Filtering-Using-Natural-Language.md>)
  - [Applying Filters From the Filter Panel](<./Searching-and-Filtering-in-the-Inventory/Applying-Filters-From-the-Filter-Panel.md>)
  - [Searching for Filter Groups](<./Searching-and-Filtering-in-the-Inventory/Searching-for-Filter-Groups.md>)
  - [Displaying and Hiding Filters](<./Searching-and-Filtering-in-the-Inventory/Displaying-and-Hiding-Filters.md>)
  - [Saving Search Results](<./Searching-and-Filtering-in-the-Inventory/Saving-Search-Results.md>)
  - [Viewing Filtered Fact Sheets in Reports](<./Searching-and-Filtering-in-the-Inventory/Viewing-Filtered-Fact-Sheets-in-Reports.md>)
